==> npm-package-json-lint-config-bob-1.0.1.tgz: package/README.md <==
<div align="center">
  <h1>npm-package-json-lint-config-bob</h1>
  <a href="https://npmjs.com/package/npm-package-json-lint-config-bob">
    <img alt="npm" src="https://img.shields.io/npm/v/npm-package-json-lint-config-bob.svg">
  </a>
  <a href="https://github.com/bconnorwhite/npm-package-json-lint-config-bob">
    <img alt="typescript" src="https://img.shields.io/github/languages/top/bconnorwhite/npm-package-json-lint-config-bob.svg">
  </a>
  <a href="https://github.com/bconnorwhite/npm-package-json-lint-config-bob">
    <img alt="GitHub stars" src="https://img.shields.io/github/stars/bconnorwhite/npm-package-json-lint-config-bob?label=Stars%20Appreciated%21&style=social">
  </a>
  <a href="https://twitter.com/bconnorwhite">
    <img alt="Twitter Follow" src="https://img.shields.io/twitter/follow/bconnorwhite.svg?label=%40bconnorwhite&style=social">
  </a>
</div>

<br />

> npm-package-json-lint for packages built with @bconnorwhite/bob.

## Installation

```bash
yarn add npm-package-json-lint-config-bob
```

```bash
npm install npm-package-json-lint-config-bob
```

<br />

<h2>Dev Dependencies<img align="right" alt="David" src="https://img.shields.io/david/dev/bconnorwhite/npm-package-json-lint-config-bob.svg"></h2>

- [@bconnorwhite/bob](https://www.npmjs.com/package/@bconnorwhite/bob): Bob is a toolkit for TypeScript projects

<br />

<h2>License <img align="right" alt="license" src="https://img.shields.io/npm/l/npm-package-json-lint-config-bob.svg"></h2>

[MIT](https://opensource.org/licenses/MIT)

==> npm-package-json-lint-config-bob-1.1.0.tgz: package/README.md <==
<div align="center">
  <h1>npm-package-json-lint-config-bob</h1>
  <a href="https://npmjs.com/package/npm-package-json-lint-config-bob">
    <img alt="npm" src="https://img.shields.io/npm/v/npm-package-json-lint-config-bob.svg">
  </a>
  <a href="https://github.com/bconnorwhite/npm-package-json-lint-config-bob">
    <img alt="typescript" src="https://img.shields.io/badge/TypeScript-%F0%9F%91%8D-blue.svg">
  </a>
  <a href="https://github.com/bconnorwhite/npm-package-json-lint-config-bob">
    <img alt="GitHub stars" src="https://img.shields.io/github/stars/bconnorwhite/npm-package-json-lint-config-bob?label=Stars%20Appreciated%21&style=social">
  </a>
  <a href="https://twitter.com/bconnorwhite">
    <img alt="Twitter Follow" src="https://img.shields.io/twitter/follow/bconnorwhite.svg?label=%40bconnorwhite&style=social">
  </a>
</div>

<br />

> NPM package.json lint configuration for packages built with @bconnorwhite/bob.

## Installation

```bash
yarn add npm-package-json-lint-config-bob
```

```bash
npm install npm-package-json-lint-config-bob
```

<br />

## Usage

In `.npmpackagejsonlintrc.json` or the `npmpackagejsonlint` field in package.json:

```json
{
  "extends": "npm-package-json-lint-config-bob"
}
```

<br />

<h2>Peer Dependencies<img align="right" alt="David" src="https://img.shields.io/david/peer/bconnorwhite/npm-package-json-lint-config-bob.svg"></h2>

- [npm-package-json-lint](https://www.npmjs.com/package/npm-package-json-lint): Configurable linter for package.json files.

<br />

<h2>Dev Dependencies<img align="right" alt="David" src="https://img.shields.io/david/dev/bconnorwhite/npm-package-json-lint-config-bob.svg"></h2>

- [@bconnorwhite/bob](https://www.npmjs.com/package/@bconnorwhite/bob): Bob is a toolkit for TypeScript projects
- [jest](https://www.npmjs.com/package/jest): Delightful JavaScript Testing.

<br />

<h2>License <img align="right" alt="license" src="https://img.shields.io/npm/l/npm-package-json-lint-config-bob.svg"></h2>

[MIT](https://opensource.org/licenses/MIT)
